from sqlalchemy.orm import Session
from services.data import DataService
from services.upload import UploadService
from services.box import BoxService
from services.tcgplayer import TCGPlayerService
from services.pricing import PricingService
from services.file import FileService
from services.product import ProductService
from services.inventory import InventoryService
from fastapi import Depends, Form
from db.database import get_db
from schemas.file import FileMetadata


## file 
# file
def get_file_service(db: Session = Depends(get_db)) -> FileService:
    """Dependency injection for FileService"""
    return FileService(db)

# metadata
def get_file_metadata(
        type: str = Form(...),
        source: str = Form(...)
    ) -> FileMetadata:
    """Dependency injection for FileMetadata"""
    return FileMetadata(type=type, source=source)

# product
def get_product_service(db: Session = Depends(get_db), file_service: FileService = Depends(get_file_service)) -> ProductService:
    """Dependency injection for ProductService"""
    return ProductService(db, file_service)


## Inventory
def get_inventory_service(db: Session = Depends(get_db)) -> InventoryService:
    """Dependency injection for InventoryService"""
    return InventoryService(db)

## Upload

def get_upload_service(db: Session = Depends(get_db)) -> UploadService:
    """Dependency injection for UploadService"""
    return UploadService(db)

## box

def get_box_service(db: Session = Depends(get_db), inventory_service: InventoryService = Depends(get_inventory_service)) -> BoxService:
    """Dependency injection for BoxService"""
    return BoxService(db, inventory_service)

## Pricing

def get_pricing_service(db: Session = Depends(get_db)) -> PricingService:
    """Dependency injection for PricingService"""
    return PricingService(db)

## tcgplayer

def get_tcgplayer_service(
        db: Session = Depends(get_db),
        pricing_service: PricingService = Depends(get_pricing_service)
        ) -> TCGPlayerService:
    """Dependency injection for TCGPlayerService"""
    return TCGPlayerService(db, pricing_service)

## Data
def get_data_service(
        db: Session = Depends(get_db), 
        tcgplayer_service: TCGPlayerService = Depends(get_tcgplayer_service)
        ) -> DataService:
    """Dependency injection for DataService"""
    return DataService(db, tcgplayer_service)

